@@ -86,7 +86,7 @@ int SkinSpritesData::intData(const QString& name) const
   {
     QString msg;
     QTextStream(&msg) << i18n("Error - Unknown skin int data: ") << name;
-    KMessageBox::error(nullptr, msg, i18n("Fatal Error"));
+    KMessageBox::error(nullptr, msg, i18nc("@title:window", "Fatal Error"));
     exit(1);    
   }
   else
@@ -102,7 +102,7 @@ const QString& SkinSpritesData::strData(const QString& name) const
   {
     QString msg;
     QTextStream(&msg) << i18n("Error - Unknown skin string data: ") << name;
-    KMessageBox::error(nullptr, msg, i18n("Fatal Error"));
+    KMessageBox::error(nullptr, msg, i18nc("@title:window", "Fatal Error"));
     exit(1);    
   }
   else
